# Examples

Here are a few examples of using the CSDMS GeoTiff data component,
*bmi-geotiff*.

* `geotiff.ipynb` and `bmi-geotiff.ipynb`: These Jupyter Notebooks show
  how to call the GeoTiff data component through its API and its BMI, respectively.
* `example-pan.py`: An example Python script showing how to load and display a panchromatic image.
* `example-rgb.py`: An example Python script showing how to load and display a three-band image.
* `example-rgb.png`: The saved output from `example-rgb.py`.
* `RGB.byte.tif`: A test GeoTIFF file [borrowed](https://github.com/rasterio/rasterio/blob/master/tests/data/RGB.byte.tif) from the [rasterio](https://github.com/rasterio/rasterio) project.
* `config.yaml`: A sample configuration file used to pass parameters to the GeoTiff data component.
